==> confixx_3.3.1.orig.tar.gz: confixx-3.3.1.orig/html/poplogin/bottom.php <==
<?php
######### Confixx(R) 3.2 Professional ############
####### Copyright SWsoft, Inc. 2004-2006 ##########
##### http://www.swsoft.com - info@swsoft.com #####

include_once("auth.php"); 

if (strpos($HTTP_USER_AGENT,"IE") > 0){
  $chars = "90";
}else{
  $chars = "64";
}
?>
<!DOCTYPE HTML PUBLIC "-//W3C//DTD HTML 4.01 Transitional//EN" "http://www.w3.org/TR/html4/loose.dtd">
<HTML>
<HEAD>
<META content="text/html; charset=<? echo $lang_html_charset; ?>" http-equiv=Content-Type>
<LINK href="<?=$strSkinName?>/style.css" rel=stylesheet type=text/css>
</HEAD>
<body background="<?=$strSkinName?>/pics/bg_bottom.jpg" leftmargin=0 topmargin=0 marginwidth=0 marginheight=0>
<form name=frmHelp>
<table width="100%" border=0 cellspacing=0 cellpadding=0>
        <tr>
                <td><img src="<?=$strSkinName?>/pics/bg_bottom_left.jpg" width=19 height=41></td>
                <td width="90%" background="<?=$strSkinName?>/pics/bg_bottom_mid.jpg"><input type=text class=help value="" size=<? echo $chars ?> name=txtHelp onFocus="this.blur();" readonly></td>
                <td><img src="<?=$strSkinName?>/pics/bg_bottom_curve.jpg" width=42 height=41></td>
                <td>
                        <table width="100%" border=0 cellspacing=0 cellpadding=3>
                                <tr>
                                        <td><img src="<?=$strSkinName?>/pics/alpha.gif" width=40 height=10>   </td>
                                        <td>
<!--										
										<img src="<?=$strSkinName?>/pics/logo-2.gif" width=32 height=22>
-->										
										</td>
                                        <td nowrap>SWsoft Inc.</td>
                                </tr>
                        </table>
                </td>
                <td><img src="<?=$strSkinName?>/pics/bg_bottom_right.jpg" width=13 height=41></td>
        </tr>
</table>
</form>
</body>
</html>

==> confixx_3.3.3.orig.tar.gz: confixx-3.3.3.orig/html/poplogin/bottom.php <==
<?php
######### Confixx(R) 3.2 Professional ############
####### Copyright SWsoft, Inc. 2004-2006 ##########
##### http://www.swsoft.com - info@swsoft.com #####

include_once("auth.php"); 

if (strpos($HTTP_USER_AGENT,"IE") > 0){
  $chars = "90";
}else{
  $chars = "64";
}
?>
<!DOCTYPE HTML PUBLIC "-//W3C//DTD HTML 4.01 Transitional//EN" "http://www.w3.org/TR/html4/loose.dtd">
<HTML>
<HEAD>
<META content="text/html; charset=<? echo $lang_html_charset; ?>" http-equiv=Content-Type>
<LINK href="<?=$strSkinName?>/style.css" rel=stylesheet type=text/css>
</HEAD>
<body background="<?=$strSkinName?>/pics/bg_bottom.jpg" leftmargin=0 topmargin=0 marginwidth=0 marginheight=0>
<form name=frmHelp>
<table width="100%" border=0 cellspacing=0 cellpadding=0>
        <tr>
                <td><img src="<?=$strSkinName?>/pics/bg_bottom_left.jpg" width=19 height=41></td>
                <td width="90%" background="<?=$strSkinName?>/pics/bg_bottom_mid.jpg"><input type=text class=help value="" size=<? echo $chars ?> name=txtHelp onFocus="this.blur();" readonly></td>
                <td><img src="<?=$strSkinName?>/pics/bg_bottom_curve.jpg" width=42 height=41></td>
                <td>
                        <table width="100%" border=0 cellspacing=0 cellpadding=3>
                                <tr>
                                        <td><img src="<?=$strSkinName?>/pics/alpha.gif" width=40 height=10>   </td>
                                        <td>
<!--										
										<img src="<?=$strSkinName?>/pics/logo-2.gif" width=32 height=22>
-->										
										</td>
                                        <td nowrap><a href="http://www.parallels.com" target="_blank" style="text-decoration: none; color: #333333; font-size: 11px; font-family: Tahoma, Arial, Helvetica, sans-serif;">&copy; 2008 Parallels GmbH</a></td>
                                </tr>
                        </table>
                </td>
                <td><img src="<?=$strSkinName?>/pics/bg_bottom_right.jpg" width=13 height=41></td>
        </tr>
</table>
</form>
</body>
</html>
